@@ -12,13 +12,14 @@ build_time_vars = {'ABIFLAGS': '',
  'BASECFLAGS': '-Wsign-compare',
  'BASECPPFLAGS': '',
  'BASEMODLIBS': '',
- 'BINDIR': '/src/build_linux/deps/Release/python/bin',
- 'BINLIBDEST': '/src/build_linux/deps/Release/python/lib/python3.11',
+ 'BINDIR': '/home/builder/build_linux/deps_x64/Release/python/bin',
+ 'BINLIBDEST': '/home/builder/build_linux/deps_x64/Release/python/lib/python3.11',
  'BLDLIBRARY': 'libpython3.11.a',
- 'BLDSHARED': 'gcc -pthread -shared -L/src/build_linux/deps/Release/ffi/lib '
-              '-L/src/build_linux/deps/Release/sqlite/lib '
-              '-L/src/build_linux/deps/Release/ssl/lib '
-              '-L/src/build_linux/deps/Release/ssl/lib64',
+ 'BLDSHARED': 'gcc -pthread -shared '
+              '-L/home/builder/build_linux/deps_x64/Release/ffi/lib '
+              '-L/home/builder/build_linux/deps_x64/Release/sqlite/lib '
+              '-L/home/builder/build_linux/deps_x64/Release/ssl/lib '
+              '-L/home/builder/build_linux/deps_x64/Release/ssl/lib64',
  'BOOTSTRAP_HEADERS': '\\',
  'BUILDEXE': '',
  'BUILDPYTHON': 'python',
@@ -38,33 +39,34 @@ build_time_vars = {'ABIFLAGS': '',
                             '-Werror=implicit-function-declaration '
                             '-fvisibility=hidden',
  'CONFIGURE_CPPFLAGS': '-fPIC',
- 'CONFIGURE_LDFLAGS': '-L/src/build_linux/deps/Release/ffi/lib '
-                      '-L/src/build_linux/deps/Release/sqlite/lib '
-                      '-L/src/build_linux/deps/Release/ssl/lib '
-                      '-L/src/build_linux/deps/Release/ssl/lib64',
+ 'CONFIGURE_LDFLAGS': '-L/home/builder/build_linux/deps_x64/Release/ffi/lib '
+                      '-L/home/builder/build_linux/deps_x64/Release/sqlite/lib '
+                      '-L/home/builder/build_linux/deps_x64/Release/ssl/lib '
+                      '-L/home/builder/build_linux/deps_x64/Release/ssl/lib64',
  'CONFIGURE_LDFLAGS_NODIST': '-fno-semantic-interposition',
  'CONFIGURE_LDFLAGS_NOLTO': '',
- 'CONFIG_ARGS': "'--prefix=/src/build_linux/deps/Release/python' "
-                "'--with-openssl=/src/build_linux/deps/Release/ssl' "
+ 'CONFIG_ARGS': "'--prefix=/home/builder/build_linux/deps_x64/Release/python' "
+                "'--with-openssl=/home/builder/build_linux/deps_x64/Release/ssl' "
                 "'--enable-optimizations' "
-                "'PKG_CONFIG_PATH=/src/build_linux/deps/Release/ffi/lib/pkgconfig:/src/build_linux/deps/Release/sqlite/lib/pkgconfig:/src/build_linux/deps/Release/ssl/lib/pkgconfig:/src/build_linux/deps/Release/ssl/lib64/pkgconfig' "
+                "'PKG_CONFIG_PATH=/home/builder/build_linux/deps_x64/Release/ffi/lib/pkgconfig:/home/builder/build_linux/deps_x64/Release/sqlite/lib/pkgconfig:/home/builder/build_linux/deps_x64/Release/ssl/lib/pkgconfig:/home/builder/build_linux/deps_x64/Release/ssl/lib64/pkgconfig' "
                 "'CFLAGS=-fPIC ' "
-                "'LDFLAGS=-L/src/build_linux/deps/Release/ffi/lib "
-                '-L/src/build_linux/deps/Release/sqlite/lib '
-                '-L/src/build_linux/deps/Release/ssl/lib '
-                "-L/src/build_linux/deps/Release/ssl/lib64  ' 'CPPFLAGS=-fPIC "
-                "' 'ZLIB_CFLAGS=-I/src/build_linux/deps/Release/zlib/include' "
-                "'ZLIB_LIBS=/src/build_linux/deps/Release/zlib/lib/libz.a' "
-                "'BZIP2_CFLAGS=-I/src/build_linux/deps/Release/bzip2/include' "
-                "'BZIP2_LIBS=/src/build_linux/deps/Release/bzip2/lib/libbz2.a' "
-                "'LIBLZMA_CFLAGS=-I/src/build_linux/deps/Release/lzma/include' "
-                "'LIBLZMA_LIBS=/src/build_linux/deps/Release/lzma/lib/liblzma.a'",
- 'CONFINCLUDEDIR': '/src/build_linux/deps/Release/python/include',
- 'CONFINCLUDEPY': '/src/build_linux/deps/Release/python/include/python3.11',
+                "'LDFLAGS=-L/home/builder/build_linux/deps_x64/Release/ffi/lib "
+                '-L/home/builder/build_linux/deps_x64/Release/sqlite/lib '
+                '-L/home/builder/build_linux/deps_x64/Release/ssl/lib '
+                "-L/home/builder/build_linux/deps_x64/Release/ssl/lib64  ' "
+                "'CPPFLAGS=-fPIC ' "
+                "'ZLIB_CFLAGS=-I/home/builder/build_linux/deps_x64/Release/zlib/include' "
+                "'ZLIB_LIBS=/home/builder/build_linux/deps_x64/Release/zlib/lib/libz.a' "
+                "'BZIP2_CFLAGS=-I/home/builder/build_linux/deps_x64/Release/bzip2/include' "
+                "'BZIP2_LIBS=/home/builder/build_linux/deps_x64/Release/bzip2/lib/libbz2.a' "
+                "'LIBLZMA_CFLAGS=-I/home/builder/build_linux/deps_x64/Release/lzma/include' "
+                "'LIBLZMA_LIBS=/home/builder/build_linux/deps_x64/Release/lzma/lib/liblzma.a'",
+ 'CONFINCLUDEDIR': '/home/builder/build_linux/deps_x64/Release/python/include',
+ 'CONFINCLUDEPY': '/home/builder/build_linux/deps_x64/Release/python/include/python3.11',
  'COREPYTHONPATH': '',
- 'COVERAGE_INFO': '/src/build_linux/deps/build/python/src/external_python/coverage.info',
+ 'COVERAGE_INFO': '/home/builder/build_linux/deps_x64/build/python/src/external_python/coverage.info',
  'COVERAGE_LCOV_OPTIONS': '--rc lcov_branch_coverage=1',
- 'COVERAGE_REPORT': '/src/build_linux/deps/build/python/src/external_python/lcov-report',
+ 'COVERAGE_REPORT': '/home/builder/build_linux/deps_x64/build/python/src/external_python/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--rc lcov_branch_coverage=1 --branch-coverage '
                             '--title "CPython 3.11 LCOV report [commit $(shell '
                             ')]"',
@@ -77,13 +79,13 @@ build_time_vars = {'ABIFLAGS': '',
  'DEEPFREEZE_DEPS': './Tools/scripts/deepfreeze.py _bootstrap_python '
                     './Programs/_freeze_module.py \\',
  'DEEPFREEZE_OBJS': 'Python/deepfreeze/deepfreeze.o',
- 'DESTDIRS': '/src/build_linux/deps/Release/python '
-             '/src/build_linux/deps/Release/python/lib '
-             '/src/build_linux/deps/Release/python/lib/python3.11 '
-             '/src/build_linux/deps/Release/python/lib/python3.11/lib-dynload',
- 'DESTLIB': '/src/build_linux/deps/Release/python/lib/python3.11',
+ 'DESTDIRS': '/home/builder/build_linux/deps_x64/Release/python '
+             '/home/builder/build_linux/deps_x64/Release/python/lib '
+             '/home/builder/build_linux/deps_x64/Release/python/lib/python3.11 '
+             '/home/builder/build_linux/deps_x64/Release/python/lib/python3.11/lib-dynload',
+ 'DESTLIB': '/home/builder/build_linux/deps_x64/Release/python/lib/python3.11',
  'DESTPATH': '',
- 'DESTSHARED': '/src/build_linux/deps/Release/python/lib/python3.11/lib-dynload',
+ 'DESTSHARED': '/home/builder/build_linux/deps_x64/Release/python/lib/python3.11/lib-dynload',
  'DFLAGS': '',
  'DIRMODE': 755,
  'DIST': 'README.rst ChangeLog configure configure.ac acconfig.h pyconfig.h.in '
@@ -607,12 +609,12 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE__GETPTY': 0,
  'HOSTRUNNER': '',
  'HOST_GNU_TYPE': 'x86_64-pc-linux-gnu',
- 'INCLDIRSTOMAKE': '/src/build_linux/deps/Release/python/include '
-                   '/src/build_linux/deps/Release/python/include '
-                   '/src/build_linux/deps/Release/python/include/python3.11 '
-                   '/src/build_linux/deps/Release/python/include/python3.11',
- 'INCLUDEDIR': '/src/build_linux/deps/Release/python/include',
- 'INCLUDEPY': '/src/build_linux/deps/Release/python/include/python3.11',
+ 'INCLDIRSTOMAKE': '/home/builder/build_linux/deps_x64/Release/python/include '
+                   '/home/builder/build_linux/deps_x64/Release/python/include '
+                   '/home/builder/build_linux/deps_x64/Release/python/include/python3.11 '
+                   '/home/builder/build_linux/deps_x64/Release/python/include/python3.11',
+ 'INCLUDEDIR': '/home/builder/build_linux/deps_x64/Release/python/include',
+ 'INCLUDEPY': '/home/builder/build_linux/deps_x64/Release/python/include/python3.11',
  'INSTALL': '/usr/bin/install -c',
  'INSTALL_DATA': '/usr/bin/install -c -m 644',
  'INSTALL_PROGRAM': '/usr/bin/install -c',
@@ -622,20 +624,21 @@ build_time_vars = {'ABIFLAGS': '',
  'IO_H': 'Modules/_io/_iomodule.h',
  'IO_OBJS': '\\',
  'LDCXXSHARED': 'g++ -pthread -shared',
- 'LDFLAGS': '-L/src/build_linux/deps/Release/ffi/lib '
-            '-L/src/build_linux/deps/Release/sqlite/lib '
-            '-L/src/build_linux/deps/Release/ssl/lib '
-            '-L/src/build_linux/deps/Release/ssl/lib64',
+ 'LDFLAGS': '-L/home/builder/build_linux/deps_x64/Release/ffi/lib '
+            '-L/home/builder/build_linux/deps_x64/Release/sqlite/lib '
+            '-L/home/builder/build_linux/deps_x64/Release/ssl/lib '
+            '-L/home/builder/build_linux/deps_x64/Release/ssl/lib64',
  'LDLIBRARY': 'libpython3.11.a',
  'LDLIBRARYDIR': '',
- 'LDSHARED': 'gcc -pthread -shared -L/src/build_linux/deps/Release/ffi/lib '
-             '-L/src/build_linux/deps/Release/sqlite/lib '
-             '-L/src/build_linux/deps/Release/ssl/lib '
-             '-L/src/build_linux/deps/Release/ssl/lib64',
+ 'LDSHARED': 'gcc -pthread -shared '
+             '-L/home/builder/build_linux/deps_x64/Release/ffi/lib '
+             '-L/home/builder/build_linux/deps_x64/Release/sqlite/lib '
+             '-L/home/builder/build_linux/deps_x64/Release/ssl/lib '
+             '-L/home/builder/build_linux/deps_x64/Release/ssl/lib64',
  'LDVERSION': '3.11',
  'LIBC': '',
- 'LIBDEST': '/src/build_linux/deps/Release/python/lib/python3.11',
- 'LIBDIR': '/src/build_linux/deps/Release/python/lib',
+ 'LIBDEST': '/home/builder/build_linux/deps_x64/Release/python/lib/python3.11',
+ 'LIBDIR': '/home/builder/build_linux/deps_x64/Release/python/lib',
  'LIBEXPAT_A': 'Modules/expat/libexpat.a',
  'LIBEXPAT_CFLAGS': '-I./Modules/expat -Wsign-compare -DNDEBUG -g -fwrapv -O3 '
                     '-Wall -fPIC -fPIC -fno-semantic-interposition -std=c11 '
@@ -646,7 +649,7 @@ build_time_vars = {'ABIFLAGS': '',
                     '-I. -I./Include -fPIC -fPIC',
  'LIBEXPAT_HEADERS': '\\',
  'LIBEXPAT_OBJS': '\\',
- 'LIBFFI_INCLUDEDIR': '/src/build_linux/deps/Release/ffi/include',
+ 'LIBFFI_INCLUDEDIR': '/home/builder/build_linux/deps_x64/Release/ffi/include',
  'LIBM': '-lm',
  'LIBMPDEC_A': 'Modules/_decimal/libmpdec/libmpdec.a',
  'LIBMPDEC_CFLAGS': '-I./Modules/_decimal/libmpdec -DCONFIG_64=1 -DANSI=1 '
@@ -661,8 +664,8 @@ build_time_vars = {'ABIFLAGS': '',
  'LIBMPDEC_OBJS': '\\',
  'LIBOBJDIR': 'Python/',
  'LIBOBJS': '',
- 'LIBPC': '/src/build_linux/deps/Release/python/lib/pkgconfig',
- 'LIBPL': '/src/build_linux/deps/Release/python/lib/python3.11/config-3.11-x86_64-linux-gnu',
+ 'LIBPC': '/home/builder/build_linux/deps_x64/Release/python/lib/pkgconfig',
+ 'LIBPL': '/home/builder/build_linux/deps_x64/Release/python/lib/python3.11/config-3.11-x86_64-linux-gnu',
  'LIBPYTHON': '',
  'LIBRARY': 'libpython3.11.a',
  'LIBRARY_DEPS': 'libpython3.11.a',
@@ -683,13 +686,13 @@ build_time_vars = {'ABIFLAGS': '',
  'LOCALMODLIBS': '',
  'MACHDEP': 'linux',
  'MACHDEP_OBJS': '',
- 'MACHDESTLIB': '/src/build_linux/deps/Release/python/lib/python3.11',
+ 'MACHDESTLIB': '/home/builder/build_linux/deps_x64/Release/python/lib/python3.11',
  'MACOSX_DEPLOYMENT_TARGET': '',
  'MAINCC': 'gcc -pthread',
  'MAJOR_IN_MKDEV': 0,
  'MAJOR_IN_SYSMACROS': 1,
  'MAKESETUP': './Modules/makesetup',
- 'MANDIR': '/src/build_linux/deps/Release/python/share/man',
+ 'MANDIR': '/home/builder/build_linux/deps_x64/Release/python/share/man',
  'MKDIR_P': '/usr/bin/mkdir -p',
  'MODBUILT_NAMES': 'atexit  faulthandler  posix  _signal  _tracemalloc  '
                    '_codecs  _collections  errno  _io  itertools  _sre  '
@@ -716,8 +719,8 @@ build_time_vars = {'ABIFLAGS': '',
  'MODULE_AUDIOOP_LDFLAGS': '-lm',
  'MODULE_AUDIOOP_STATE': 'yes',
  'MODULE_BINASCII_CFLAGS': '-DUSE_ZLIB_CRC32 '
-                           '-I/src/build_linux/deps/Release/zlib/include',
- 'MODULE_BINASCII_LDFLAGS': '/src/build_linux/deps/Release/zlib/lib/libz.a',
+                           '-I/home/builder/build_linux/deps_x64/Release/zlib/include',
+ 'MODULE_BINASCII_LDFLAGS': '/home/builder/build_linux/deps_x64/Release/zlib/lib/libz.a',
  'MODULE_BINASCII_STATE': 'yes',
  'MODULE_CMATH_DEPS': './Modules/_math.h',
  'MODULE_CMATH_LDFLAGS': '-lm',
@@ -756,8 +759,8 @@ build_time_vars = {'ABIFLAGS': '',
  'MODULE_XXLIMITED_35_STATE': 'yes',
  'MODULE_XXLIMITED_STATE': 'yes',
  'MODULE_XXSUBTYPE_LDFLAGS': '',
- 'MODULE_ZLIB_CFLAGS': '-I/src/build_linux/deps/Release/zlib/include',
- 'MODULE_ZLIB_LDFLAGS': '/src/build_linux/deps/Release/zlib/lib/libz.a',
+ 'MODULE_ZLIB_CFLAGS': '-I/home/builder/build_linux/deps_x64/Release/zlib/include',
+ 'MODULE_ZLIB_LDFLAGS': '/home/builder/build_linux/deps_x64/Release/zlib/lib/libz.a',
  'MODULE_ZLIB_STATE': 'yes',
  'MODULE__ABC_LDFLAGS': '',
  'MODULE__ASYNCIO_STATE': 'yes',
@@ -780,8 +783,8 @@ build_time_vars = {'ABIFLAGS': '',
                         './Modules/_blake2/blake2module.h ./Modules/hashlib.h',
  'MODULE__BLAKE2_LDFLAGS': '',
  'MODULE__BLAKE2_STATE': 'yes',
- 'MODULE__BZ2_CFLAGS': '-I/src/build_linux/deps/Release/bzip2/include',
- 'MODULE__BZ2_LDFLAGS': '/src/build_linux/deps/Release/bzip2/lib/libbz2.a',
+ 'MODULE__BZ2_CFLAGS': '-I/home/builder/build_linux/deps_x64/Release/bzip2/include',
+ 'MODULE__BZ2_LDFLAGS': '/home/builder/build_linux/deps_x64/Release/bzip2/lib/libbz2.a',
  'MODULE__BZ2_STATE': 'yes',
  'MODULE__CODECS_CN_STATE': 'yes',
  'MODULE__CODECS_HK_STATE': 'yes',
@@ -812,9 +815,9 @@ build_time_vars = {'ABIFLAGS': '',
  'MODULE__ELEMENTTREE_STATE': 'yes',
  'MODULE__FUNCTOOLS_LDFLAGS': '',
  'MODULE__GDBM_STATE': 'missing',
- 'MODULE__HASHLIB_CFLAGS': '-I/src/build_linux/deps/Release/ssl/include',
+ 'MODULE__HASHLIB_CFLAGS': '-I/home/builder/build_linux/deps_x64/Release/ssl/include',
  'MODULE__HASHLIB_DEPS': './Modules/hashlib.h',
- 'MODULE__HASHLIB_LDFLAGS': '-L/src/build_linux/deps/Release/ssl/lib   '
+ 'MODULE__HASHLIB_LDFLAGS': '-L/home/builder/build_linux/deps_x64/Release/ssl/lib   '
                             '-lcrypto',
  'MODULE__HASHLIB_STATE': 'yes',
  'MODULE__HEAPQ_STATE': 'yes',
@@ -825,8 +828,8 @@ build_time_vars = {'ABIFLAGS': '',
  'MODULE__JSON_STATE': 'yes',
  'MODULE__LOCALE_LDFLAGS': '',
  'MODULE__LSPROF_STATE': 'yes',
- 'MODULE__LZMA_CFLAGS': '-I/src/build_linux/deps/Release/lzma/include',
- 'MODULE__LZMA_LDFLAGS': '/src/build_linux/deps/Release/lzma/lib/liblzma.a',
+ 'MODULE__LZMA_CFLAGS': '-I/home/builder/build_linux/deps_x64/Release/lzma/include',
+ 'MODULE__LZMA_LDFLAGS': '/home/builder/build_linux/deps_x64/Release/lzma/lib/liblzma.a',
  'MODULE__LZMA_STATE': 'yes',
  'MODULE__MD5_DEPS': './Modules/hashlib.h',
  'MODULE__MD5_STATE': 'yes',
@@ -856,7 +859,7 @@ build_time_vars = {'ABIFLAGS': '',
  'MODULE__SOCKET_DEPS': './Modules/socketmodule.h ./Modules/addrinfo.h '
                         './Modules/getaddrinfo.c ./Modules/getnameinfo.c',
  'MODULE__SOCKET_STATE': 'yes',
- 'MODULE__SQLITE3_CFLAGS': '-I/src/build_linux/deps/Release/sqlite/include  '
+ 'MODULE__SQLITE3_CFLAGS': '-I/home/builder/build_linux/deps_x64/Release/sqlite/include  '
                            '-I./Modules/_sqlite',
  'MODULE__SQLITE3_DEPS': './Modules/_sqlite/connection.h '
                          './Modules/_sqlite/cursor.h '
@@ -864,17 +867,17 @@ build_time_vars = {'ABIFLAGS': '',
                          './Modules/_sqlite/module.h '
                          './Modules/_sqlite/prepare_protocol.h '
                          './Modules/_sqlite/row.h ./Modules/_sqlite/util.h',
- 'MODULE__SQLITE3_LDFLAGS': '-L/src/build_linux/deps/Release/sqlite/lib '
+ 'MODULE__SQLITE3_LDFLAGS': '-L/home/builder/build_linux/deps_x64/Release/sqlite/lib '
                             '-lsqlite3',
  'MODULE__SQLITE3_STATE': 'yes',
  'MODULE__SRE_LDFLAGS': '',
- 'MODULE__SSL_CFLAGS': '-I/src/build_linux/deps/Release/ssl/include',
+ 'MODULE__SSL_CFLAGS': '-I/home/builder/build_linux/deps_x64/Release/ssl/include',
  'MODULE__SSL_DEPS': './Modules/_ssl.h ./Modules/_ssl/cert.c '
                      './Modules/_ssl/debughelpers.c ./Modules/_ssl/misc.c '
                      './Modules/_ssl_data.h ./Modules/_ssl_data_111.h '
                      './Modules/_ssl_data_300.h ./Modules/socketmodule.h',
- 'MODULE__SSL_LDFLAGS': '-L/src/build_linux/deps/Release/ssl/lib  -lssl '
-                        '-lcrypto',
+ 'MODULE__SSL_LDFLAGS': '-L/home/builder/build_linux/deps_x64/Release/ssl/lib  '
+                        '-lssl -lcrypto',
  'MODULE__SSL_STATE': 'yes',
  'MODULE__STATISTICS_LDFLAGS': '-lm',
  'MODULE__STATISTICS_STATE': 'yes',
@@ -904,8 +907,8 @@ build_time_vars = {'ABIFLAGS': '',
  'MVWDELCH_IS_EXPRESSION': 1,
  'NO_AS_NEEDED': '-Wl,--no-as-needed',
  'OBJECT_OBJS': '\\',
- 'OPENSSL_INCLUDES': '-I/src/build_linux/deps/Release/ssl/include',
- 'OPENSSL_LDFLAGS': '-L/src/build_linux/deps/Release/ssl/lib',
+ 'OPENSSL_INCLUDES': '-I/home/builder/build_linux/deps_x64/Release/ssl/include',
+ 'OPENSSL_LDFLAGS': '-L/home/builder/build_linux/deps_x64/Release/ssl/lib',
  'OPENSSL_LIBS': '-lssl -lcrypto',
  'OPENSSL_RPATH': '',
  'OPT': '-DNDEBUG -g -fwrapv -O3 -Wall',
@@ -965,23 +968,23 @@ build_time_vars = {'ABIFLAGS': '',
                    '-Werror=implicit-function-declaration -fvisibility=hidden '
                    '-fprofile-use -fprofile-correction -I./Include/internal '
                    '-I. -I./Include -fPIC -DPy_BUILD_CORE',
- 'PY_CORE_LDFLAGS': '-L/src/build_linux/deps/Release/ffi/lib '
-                    '-L/src/build_linux/deps/Release/sqlite/lib '
-                    '-L/src/build_linux/deps/Release/ssl/lib '
-                    '-L/src/build_linux/deps/Release/ssl/lib64 '
+ 'PY_CORE_LDFLAGS': '-L/home/builder/build_linux/deps_x64/Release/ffi/lib '
+                    '-L/home/builder/build_linux/deps_x64/Release/sqlite/lib '
+                    '-L/home/builder/build_linux/deps_x64/Release/ssl/lib '
+                    '-L/home/builder/build_linux/deps_x64/Release/ssl/lib64 '
                     '-fno-semantic-interposition',
  'PY_CPPFLAGS': '-I. -I./Include -fPIC',
  'PY_ENABLE_SHARED': 0,
  'PY_FORMAT_SIZE_T': '"z"',
- 'PY_LDFLAGS': '-L/src/build_linux/deps/Release/ffi/lib '
-               '-L/src/build_linux/deps/Release/sqlite/lib '
-               '-L/src/build_linux/deps/Release/ssl/lib '
-               '-L/src/build_linux/deps/Release/ssl/lib64',
+ 'PY_LDFLAGS': '-L/home/builder/build_linux/deps_x64/Release/ffi/lib '
+               '-L/home/builder/build_linux/deps_x64/Release/sqlite/lib '
+               '-L/home/builder/build_linux/deps_x64/Release/ssl/lib '
+               '-L/home/builder/build_linux/deps_x64/Release/ssl/lib64',
  'PY_LDFLAGS_NODIST': '-fno-semantic-interposition',
- 'PY_LDFLAGS_NOLTO': '-L/src/build_linux/deps/Release/ffi/lib '
-                     '-L/src/build_linux/deps/Release/sqlite/lib '
-                     '-L/src/build_linux/deps/Release/ssl/lib '
-                     '-L/src/build_linux/deps/Release/ssl/lib64',
+ 'PY_LDFLAGS_NOLTO': '-L/home/builder/build_linux/deps_x64/Release/ffi/lib '
+                     '-L/home/builder/build_linux/deps_x64/Release/sqlite/lib '
+                     '-L/home/builder/build_linux/deps_x64/Release/ssl/lib '
+                     '-L/home/builder/build_linux/deps_x64/Release/ssl/lib64',
  'PY_SQLITE_ENABLE_LOAD_EXTENSION': 0,
  'PY_SQLITE_HAVE_SERIALIZE': 1,
  'PY_SSL_DEFAULT_CIPHERS': 1,
@@ -1005,7 +1008,7 @@ build_time_vars = {'ABIFLAGS': '',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
  'RUNSHARED': '',
- 'SCRIPTDIR': '/src/build_linux/deps/Release/python/lib',
+ 'SCRIPTDIR': '/home/builder/build_linux/deps_x64/Release/python/lib',
  'SETPGRP_HAVE_ARG': 0,
  'SHELL': '/bin/sh',
  'SHLIBS': '-lpthread -ldl -lm  -lutil',
@@ -1064,8 +1067,8 @@ build_time_vars = {'ABIFLAGS': '',
  'UPDATE_FILE': './Tools/scripts/update_file.py',
  'USE_COMPUTED_GOTOS': 0,
  'VERSION': '3.11',
- 'WASM_ASSETS_DIR': './src/build_linux/deps/Release/python',
- 'WASM_STDLIB': './src/build_linux/deps/Release/python/lib/python3.11/os.py',
+ 'WASM_ASSETS_DIR': './home/builder/build_linux/deps_x64/Release/python',
+ 'WASM_STDLIB': './home/builder/build_linux/deps_x64/Release/python/lib/python3.11/os.py',
  'WHEEL_PKG_DIR': '',
  'WINDOW_HAS_FLAGS': 1,
  'WITH_DECIMAL_CONTEXTVAR': 1,
@@ -1080,9 +1083,9 @@ build_time_vars = {'ABIFLAGS': '',
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/src/build_linux/deps/build/python/src/external_python',
- 'abs_srcdir': '/src/build_linux/deps/build/python/src/external_python',
- 'datarootdir': '/src/build_linux/deps/Release/python/share',
- 'exec_prefix': '/src/build_linux/deps/Release/python',
- 'prefix': '/src/build_linux/deps/Release/python',
+ 'abs_builddir': '/home/builder/build_linux/deps_x64/build/python/src/external_python',
+ 'abs_srcdir': '/home/builder/build_linux/deps_x64/build/python/src/external_python',
+ 'datarootdir': '/home/builder/build_linux/deps_x64/Release/python/share',
+ 'exec_prefix': '/home/builder/build_linux/deps_x64/Release/python',
+ 'prefix': '/home/builder/build_linux/deps_x64/Release/python',
  'srcdir': '.'}
